**Gitrex is a Graphic User Interface (GUI) application that simplifies and speeds up package upload to repository using twine**

Gitrex can be used to upload packages to pypi and test pypi with just a few clicks and less hustle.

**Download:** https://github.com/eirasmx/Gitrex/releases

> python -m pip install twine       

**NOTE:** To use Gitrex you have to install twine first